pilas.descargar.Descargar

Package pilas :: Module descargar :: Class Descargar |
[hide private]
[frames] | no frames]

# Class Descargar

source code

    PyQt4.QtGui.QDialog --+
                          |
                         Descargar

Instance Methods | [hide private]
__init__(self, parent, url, archivo_destino) | source code
downloadFile(self, url, archivo_destino) | source code
cuando_cancela(self) | source code
cuando_finalizar_request(self, request_id, error) | source code
cuando_responder_header(self, responseHeader) | source code
cuando_actualiza_descarga(self, bytes_leidos, total_bytes) | source code